Plugins/CheckerPlugins/Pep8/Pep8Fixer.py

changeset 2912
9ff696796092
parent 2895
4a44d92757f9
child 2921
9e8431cbd2cf
--- a/Plugins/CheckerPlugins/Pep8/Pep8Fixer.py	Fri Sep 13 18:49:26 2013 +0200
+++ b/Plugins/CheckerPlugins/Pep8/Pep8Fixer.py	Sat Sep 14 13:29:32 2013 +0200
@@ -4,7 +4,7 @@
 #
 
 """
-Module implementing a class to fix certain PEP 8 issues.
+Module implementing a class to fix certain code style issues.
 """
 
 import os
@@ -35,7 +35,7 @@
 
 class Pep8Fixer(QObject):
     """
     Class implementing a fixer for certain PEP 8 issues.
     """
     def __init__(self, project, filename, sourceLines, fixCodes, noFixCodes,
                  maxLineLength, inPlace):
@@ -160,7 +160,7 @@
         except (IOError, Utilities.CodingError, UnicodeError) as err:
             E5MessageBox.critical(
                 self,
-                self.trUtf8("Fix PEP 8 issues"),
+                self.trUtf8("Fix Code Style Issues"),
                 self.trUtf8(
                     """<p>Could not save the file <b>{0}</b>."""
                     """ Skipping it.</p><p>Reason: {1}</p>""")
@@ -35,7 +35,7 @@
 class Pep8Fixer(QObject):
     """
-    Class implementing a fixer for certain PEP 8 issues.
+    Class implementing a fixer for certain code style issues.
     """
     def __init__(self, project, filename, sourceLines, fixCodes, noFixCodes,

eric ide

mercurial